@@ -1,14 +1,17 @@
-## SimInf, a framework for stochastic disease spread simulations
-## Copyright (C) 2015  Pavol Bauer
-## Copyright (C) 2015 - 2019  Stefan Engblom
-## Copyright (C) 2015 - 2019  Stefan Widgren
+## This file is part of SimInf, a framework for stochastic
+## disease spread simulations.
 ##
-## This program is free software: you can redistribute it and/or modify
+## Copyright (C) 2015 Pavol Bauer
+## Copyright (C) 2017 -- 2019 Robin Eriksson
+## Copyright (C) 2015 -- 2019 Stefan Engblom
+## Copyright (C) 2015 -- 2020 Stefan Widgren
+##
+## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation, either version 3 of the License, or
 ## (at your option) any later version.
 ##
-## This program is distributed in the hope that it will be useful,
+## SimInf is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
@@ -23,11 +26,58 @@
 ##' @export
 setClass("SISe3", contains = c("SimInf_model"))
 
-##' Create a \sQuote{SISe3} model
+##' Create a \code{SISe3} model
 ##'
-##' Create a \sQuote{SISe3} model to be used by the simulation
+##' Create a \code{SISe3} model to be used by the simulation
 ##' framework.
 ##'
+##' The \code{SISe3} model contains two compartments in three age
+##' categories; number of susceptible (S_1, S_2, S_3) and number of
+##' infectious (I_1, I_2, I_3). Additionally, it contains an
+##' environmental compartment to model shedding of a pathogen to the
+##' environment. Consequently, the model has six state transitions,
+##'
+##' \deqn{S_1 \stackrel{\upsilon_1 \varphi S_1}{\longrightarrow} I_1}{
+##' S_1 -- upsilon_1 phi S_1 --> I_1}
+##'
+##' \deqn{I_1 \stackrel{\gamma_1 I_1}{\longrightarrow} S_1}{
+##' I_1 -- gamma_1 I_1 --> S_1}
+##'
+##' \deqn{S_2 \stackrel{\upsilon_2 \varphi S_2}{\longrightarrow} I_2}{
+##' S_2 -- upsilon_2 phi S_2 --> I_2}
+##'
+##' \deqn{I_2 \stackrel{\gamma_2 I_2}{\longrightarrow} S_2}{
+##' I_2 -- gamma_2 I_2 --> S_2}
+##'
+##' \deqn{S_3 \stackrel{\upsilon_3 \varphi S_3}{\longrightarrow} I_3}{
+##' S_3 -- upsilon_3 phi S_3 --> I_3}
+##'
+##' \deqn{I_3 \stackrel{\gamma_3 I_3}{\longrightarrow} S_3}{
+##' I_3 -- gamma_3 I_3 --> S_3}
+##'
+##' where the transition rate per unit of time from susceptible to
+##' infected is proportional to the concentration of the environmental
+##' contamination \eqn{\varphi}{phi} in each node. Moreover, the
+##' transition rate from infected to susceptible is the recovery rate
+##' \eqn{\gamma_1, \gamma_2, \gamma_3}, measured per individual and
+##' per unit of time. Finally, the environmental infectious pressure
+##' in each node is evolved by,
+##'
+##' \deqn{\frac{d\varphi(t)}{dt} = \frac{\alpha \left(I_1(t) + I_2(t)
+##' + I_3(t)\right)}{N(t)} - \beta(t) \varphi(t) + \epsilon}{
+##' dphi(t) / dt = alpha (I_1(t) + I_2(t) + I_3(t)) / N(t)
+##' - beta(t) phi(t) + epsilon}
+##'
+##' where \eqn{\alpha} is the average shedding rate of the pathogen to
+##' the environment per infected individual and \eqn{N = S_1 + S_2 +
+##' S_3 + I_1 + I_2 + I_3} the size of the node. The seasonal decay
+##' and removal of the pathogen is captured by \eqn{\beta(t)}. It is
+##' also possible to include a small background infectious pressure
+##' \eqn{\epsilon} to allow for other indirect sources of
+##' environmental contamination. The environmental infectious pressure
+##' \eqn{\varphi(t)}{phi(t)} in each node is evolved each time unit by
+##' the Euler forward method. The value of \eqn{\varphi(t)}{phi(t)} is
+##' saved at the time-points specified in \code{tspan}.
 ##'
 ##' The argument \code{u0} must be a \code{data.frame} with one row for
 ##' each node with the following columns:
@@ -82,8 +132,7 @@ SISe3 <- function(u0,
                   end_t2    = NULL,
                   end_t3    = NULL,
                   end_t4    = NULL,
-                  epsilon   = NULL)
-{
+                  epsilon   = NULL) {
     compartments <- c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3")
 
     ## Check arguments.
@@ -140,7 +189,8 @@ SISe3 <- function(u0,
                  dimnames = list("phi"))
 
     ldata <- matrix(as.numeric(c(end_t1, end_t2, end_t3, end_t4)),
-                    nrow = 4, byrow = TRUE)
+                    nrow = 4, byrow = TRUE,
+                    dimnames = list(c("end_t1", "end_t2", "end_t3", "end_t4")))
 
     gdata <- as.numeric(c(upsilon_1, upsilon_2, upsilon_3,
                           gamma_1, gamma_2, gamma_3, alpha,
@@ -206,7 +256,7 @@ SISe3 <- function(u0,
 ##' plot(events(model))
 ##'
 ##' ## Run the model to generate a single stochastic trajectory.
-##' result <- run(model, threads = 1)
+##' result <- run(model)
 ##'
 ##' ## Summarize the trajectory. The summary includes the number of
 ##' ## events by event type.
@@ -255,7 +305,7 @@ NULL
 ##'                end_t2 = 182, end_t3 = 273, end_t4 = 365, epsilon = 0)
 ##'
 ##' ## Run the model to generate a single stochastic trajectory.
-##' result <- run(model, threads = 1)
+##' result <- run(model)
 ##'
 ##' ## Summarize trajectory
 ##' summary(result)
