@@ -1,22 +1,24 @@
 /*
- *  SimInf, a framework for stochastic disease spread simulations
- *  Copyright (C) 2015 Pavol Bauer
- *  Copyright (C) 2017 - 2018 Robin Eriksson
- *  Copyright (C) 2015 - 2018 Stefan Engblom
- *  Copyright (C) 2015 - 2018 Stefan Widgren
+ * This file is part of SimInf, a framework for stochastic
+ * disease spread simulations.
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * Copyright (C) 2015 Pavol Bauer
+ * Copyright (C) 2017 -- 2019 Robin Eriksson
+ * Copyright (C) 2015 -- 2019 Stefan Engblom
+ * Copyright (C) 2015 -- 2019 Stefan Widgren
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * SimInf is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SimInf is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <Rdefines.h>
@@ -31,21 +33,10 @@ SEXP SISe_run(SEXP, SEXP, SEXP);
 SEXP SISe3_run(SEXP, SEXP, SEXP);
 SEXP SISe3_sp_run(SEXP, SEXP, SEXP);
 SEXP SISe_sp_run(SEXP, SEXP, SEXP);
+SEXP SimInf_have_openmp();
+SEXP SimInf_init_threads(SEXP);
 SEXP SimInf_ldata_sp(SEXP, SEXP, SEXP);
-
-/**
- * Is OpenMP available
- */
-SEXP SimInf_have_openmp()
-{
-    return Rf_ScalarLogical(
-#ifdef _OPENMP
-        1
-#else
-        0
-#endif
-        );
-}
+SEXP SimInf_trajectory(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 #define CALLDEF(name, n) {#name, (DL_FUNC) &name, n}
 
@@ -58,7 +49,9 @@ static const R_CallMethodDef callMethods[] =
     CALLDEF(SISe3_sp_run, 3),
     CALLDEF(SISe_sp_run, 3),
     CALLDEF(SimInf_have_openmp, 0),
+    CALLDEF(SimInf_init_threads, 1),
     CALLDEF(SimInf_ldata_sp, 3),
+    CALLDEF(SimInf_trajectory, 9),
     {NULL, NULL, 0}
 };
 
@@ -74,4 +67,5 @@ R_init_SimInf(DllInfo *info)
     R_useDynamicSymbols(info, FALSE);
     R_forceSymbols(info, FALSE);
     R_RegisterCCallable("SimInf", "SimInf_run", (DL_FUNC) &SimInf_run);
+    SimInf_init_threads(R_NilValue);
 }
