@@ -1,14 +1,17 @@
-## SimInf, a framework for stochastic disease spread simulations
-## Copyright (C) 2015  Pavol Bauer
-## Copyright (C) 2015 - 2017  Stefan Engblom
-## Copyright (C) 2015 - 2017  Stefan Widgren
+## This file is part of SimInf, a framework for stochastic
+## disease spread simulations.
 ##
-## This program is free software: you can redistribute it and/or modify
+## Copyright (C) 2015 Pavol Bauer
+## Copyright (C) 2017 -- 2019 Robin Eriksson
+## Copyright (C) 2015 -- 2019 Stefan Engblom
+## Copyright (C) 2015 -- 2019 Stefan Widgren
+##
+## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation, either version 3 of the License, or
 ## (at your option) any later version.
 ##
-## This program is distributed in the hope that it will be useful,
+## SimInf is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
@@ -16,7 +19,12 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-library("SimInf")
+library(SimInf)
+library(tools)
+source("util/check.R")
+
+## Specify the number of threads to use.
+set_num_threads(1)
 
 ## For debugging
 sessionInfo()
@@ -27,10 +35,7 @@ sessionInfo()
 ##
 ## The individual start in the susceptible state, with a probability
 ## of becoming infected.
-u0 <- structure(list(S = 1, I = 0),
-                .Names = c("S", "I"),
-                row.names = c(NA, -1L),
-                class = "data.frame")
+u0 <- data.frame(S = 1, I = 0)
 
 model <- SISe(u0      = u0,
               tspan   = 0:1000,
@@ -49,24 +54,26 @@ model <- SISe(u0      = u0,
               end_t4  = 365,
               epsilon = 1)
 
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(sum(trajectory(result, as.is = TRUE)), 1001L))
-stopifnot(any(trajectory(result, as.is = TRUE)[1,]))
-stopifnot(any(trajectory(result, as.is = TRUE)[2,]))
+stopifnot(any(trajectory(result, as.is = TRUE)[1, ]))
+stopifnot(any(trajectory(result, as.is = TRUE)[2, ]))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
 
 if (SimInf:::have_openmp()) {
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(sum(result_omp@U), 1001L))
-    stopifnot(any(result_omp@U[1,]))
-    stopifnot(any(result_omp@U[2,]))
+    stopifnot(any(result_omp@U[1, ]))
+    stopifnot(any(result_omp@U[2, ]))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
@@ -81,17 +88,14 @@ if (SimInf:::have_openmp()) {
 ## becoming infected.
 ##
 ## At t = 1, all individuals are moved to node = 1.
-u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
-                     I_1 = c(0, 0, 0, 0, 0, 0),
-                     S_2 = c(0, 1, 2, 3, 4, 5),
-                     I_2 = c(0, 0, 0, 0, 0, 0),
-                     S_3 = c(0, 1, 2, 3, 4, 5),
-                     I_3 = c(0, 0, 0, 0, 0, 0)),
-                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                row.names = c(NA, -6L),
-                class = "data.frame")
+u0 <- data.frame(S_1 = c(0, 1, 2, 3, 4, 5),
+                 I_1 = c(0, 0, 0, 0, 0, 0),
+                 S_2 = c(0, 1, 2, 3, 4, 5),
+                 I_2 = c(0, 0, 0, 0, 0, 0),
+                 S_3 = c(0, 1, 2, 3, 4, 5),
+                 I_3 = c(0, 0, 0, 0, 0, 0))
 
-events <- structure(list(
+events <- data.frame(
     event      = c(3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3),
     time       = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     node       = c(2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 6),
@@ -99,10 +103,7 @@ events <- structure(list(
     n          = c(1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5),
     proportion = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     select     = c(4, 5, 6, 4, 5, 6, 4, 5, 6, 4, 5, 6, 4, 5, 6),
-    shift      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)),
-    .Names = c("event", "time", "node", "dest",
-               "n", "proportion", "select", "shift"),
-    row.names = c(NA, -15L), class = "data.frame")
+    shift      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
 
 model <- SISe3(u0        = u0,
                tspan     = 0:10,
@@ -126,12 +127,12 @@ model <- SISe3(u0        = u0,
                epsilon   = 1)
 
 set.seed(123)
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
-stopifnot(all(apply(trajectory(result, as.is = TRUE)[1:6,], 1, any)))
-stopifnot(identical(sum(trajectory(result, as.is = TRUE)[1:6,11]), 45L))
-stopifnot(identical(sum(trajectory(result, as.is = TRUE)[,1]), 45L))
+stopifnot(all(apply(trajectory(result, as.is = TRUE)[1:6, ], 1, any)))
+stopifnot(identical(sum(trajectory(result, as.is = TRUE)[1:6, 11]), 45L))
+stopifnot(identical(sum(trajectory(result, as.is = TRUE)[, 1]), 45L))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
@@ -139,12 +140,14 @@ stopifnot(identical(model@events, result@events))
 
 if (SimInf:::have_openmp()) {
     set.seed(123)
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
-    stopifnot(all(apply(result_omp@U[1:6,], 1, any)))
-    stopifnot(identical(sum(result_omp@U[1:6,11]), 45L))
-    stopifnot(identical(sum(result_omp@U[,1]), 45L))
+    stopifnot(all(apply(result_omp@U[1:6, ], 1, any)))
+    stopifnot(identical(sum(result_omp@U[1:6, 11]), 45L))
+    stopifnot(identical(sum(result_omp@U[, 1]), 45L))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
@@ -160,17 +163,14 @@ if (SimInf:::have_openmp()) {
 ##
 ## At t = 1, all individuals in age category 1 and 2 are moved to node
 ## = 1 and age.
-u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
-                     I_1 = c(0, 0, 0, 0, 0, 0),
-                     S_2 = c(0, 1, 2, 3, 4, 5),
-                     I_2 = c(0, 0, 0, 0, 0, 0),
-                     S_3 = c(0, 1, 2, 3, 4, 5),
-                     I_3 = c(0, 0, 0, 0, 0, 0)),
-                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                row.names = c(NA, -6L),
-                class = "data.frame")
+u0 <- data.frame(S_1 = c(0, 1, 2, 3, 4, 5),
+                 I_1 = c(0, 0, 0, 0, 0, 0),
+                 S_2 = c(0, 1, 2, 3, 4, 5),
+                 I_2 = c(0, 0, 0, 0, 0, 0),
+                 S_3 = c(0, 1, 2, 3, 4, 5),
+                 I_3 = c(0, 0, 0, 0, 0, 0))
 
-events <- structure(list(
+events <- data.frame(
     event      = c(3, 3, 3, 3, 3, 3, 3, 3, 3, 3),
     time       = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     node       = c(2, 2, 3, 3, 4, 4, 5, 5, 6, 6),
@@ -178,10 +178,7 @@ events <- structure(list(
     n          = c(1, 1, 2, 2, 3, 3, 4, 4, 5, 5),
     proportion = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     select     = c(4, 5, 4, 5, 4, 5, 4, 5, 4, 5),
-    shift      = c(1, 2, 1, 2, 1, 2, 1, 2, 1, 2)),
-    .Names = c("event", "time", "node", "dest",
-               "n", "proportion", "select", "shift"),
-    row.names = c(NA, -15L), class = "data.frame")
+    shift      = c(1, 2, 1, 2, 1, 2, 1, 2, 1, 2))
 
 model <- SISe3(u0        = u0,
                tspan     = 0:10,
@@ -204,7 +201,7 @@ model <- SISe3(u0        = u0,
                end_t4    = 365,
                epsilon   = 1)
 
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 
@@ -222,14 +219,16 @@ stopifnot(identical(m,
                     structure(c(0L, 15L, 15L, 15L, 15L,
                                 15L, 15L, 15L, 15L, 15L, 15L),
                               .Dim = c(1L, 11L))))
-stopifnot(identical(sum(trajectory(result, as.is = TRUE)[,1]), 45L))
+stopifnot(identical(sum(trajectory(result, as.is = TRUE)[, 1]), 45L))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
 
 if (SimInf:::have_openmp()) {
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
     m <- trajectory(result, compartments = "S_2", node = 1, as.is = TRUE) +
@@ -246,7 +245,7 @@ if (SimInf:::have_openmp()) {
                         structure(c(0L, 15L, 15L, 15L, 15L,
                                     15L, 15L, 15L, 15L, 15L, 15L),
                                   .Dim = c(1L, 11L))))
-    stopifnot(identical(sum(result_omp@U[,1]), 45L))
+    stopifnot(identical(sum(result_omp@U[, 1]), 45L))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
@@ -261,14 +260,12 @@ if (SimInf:::have_openmp()) {
 ## becoming infected.
 ##
 ## No scheduled events
-u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
-                     I_1 = c(0, 0, 0, 0, 0, 0),
-                     S_2 = c(0, 1, 2, 3, 4, 5),
-                     I_2 = c(0, 0, 0, 0, 0, 0),
-                     S_3 = c(0, 1, 2, 3, 4, 5),
-                     I_3 = c(0, 0, 0, 0, 0, 0)),
-                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                row.names = c(NA, -6L), class = "data.frame")
+u0 <- data.frame(S_1 = c(0, 1, 2, 3, 4, 5),
+                 I_1 = c(0, 0, 0, 0, 0, 0),
+                 S_2 = c(0, 1, 2, 3, 4, 5),
+                 I_2 = c(0, 0, 0, 0, 0, 0),
+                 S_3 = c(0, 1, 2, 3, 4, 5),
+                 I_3 = c(0, 0, 0, 0, 0, 0))
 
 model <- SISe3(u0        = u0,
                tspan     = 0:10,
@@ -291,28 +288,32 @@ model <- SISe3(u0        = u0,
                end_t4    = 365,
                epsilon   = 1)
 
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
-stopifnot(all(trajectory(result, as.is = TRUE)[1:6,] == 0))
-stopifnot(all(apply(trajectory(result, as.is = TRUE)[seq(from=8, to=36, by=2),], 1, any)))
-stopifnot(identical(sum(trajectory(result, as.is = TRUE)[,11]), 45L))
+stopifnot(all(trajectory(result, as.is = TRUE)[1:6, ] == 0))
+stopifnot(identical(sum(trajectory(result, as.is = TRUE)[, 11]), 45L))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
 
+i <- seq(from = 8, to = 36, by = 2)
+stopifnot(all(apply(trajectory(result, as.is = TRUE)[i, ], 1, any)))
+
 if (SimInf:::have_openmp()) {
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
-    stopifnot(all(result_omp@U[1:6,] == 0))
-    stopifnot(all(apply(result_omp@U[seq(from=8, to=36, by=2),], 1, any)))
-    stopifnot(identical(sum(result_omp@U[,11]), 45L))
+    stopifnot(all(result_omp@U[1:6, ] == 0))
+    stopifnot(identical(sum(result_omp@U[, 11]), 45L))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
     stopifnot(identical(model@events, result_omp@events))
+    stopifnot(all(apply(result_omp@U[i, ], 1, any)))
 }
 
 ## 6 Nodes
@@ -323,16 +324,14 @@ if (SimInf:::have_openmp()) {
 ## of becoming infected.
 ##
 ## At t = 1, all individuals are moved to node = 1.
-u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
-                     I_1 = c(0, 0, 0, 0, 0, 0),
-                     S_2 = c(0, 1, 2, 3, 4, 5),
-                     I_2 = c(0, 0, 0, 0, 0, 0),
-                     S_3 = c(0, 1, 2, 3, 4, 5),
-                     I_3 = c(0, 0, 0, 0, 0, 0)),
-                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                row.names = c(NA, -6L), class = "data.frame")
+u0 <- data.frame(S_1 = c(0, 1, 2, 3, 4, 5),
+                 I_1 = c(0, 0, 0, 0, 0, 0),
+                 S_2 = c(0, 1, 2, 3, 4, 5),
+                 I_2 = c(0, 0, 0, 0, 0, 0),
+                 S_3 = c(0, 1, 2, 3, 4, 5),
+                 I_3 = c(0, 0, 0, 0, 0, 0))
 
-events <- structure(list(
+events <- data.frame(
     event      = c(3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3),
     time       = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     node       = c(2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 6),
@@ -340,10 +339,7 @@ events <- structure(list(
     n          = c(1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5),
     proportion = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     select     = c(4, 5, 6, 4, 5, 6, 4, 5, 6, 4, 5, 6, 4, 5, 6),
-    shift      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)),
-    .Names = c("event", "time", "node", "dest",
-               "n", "proportion", "select", "shift"),
-    row.names = c(NA, -15L), class = "data.frame")
+    shift      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
 
 model <- SISe3(u0        = u0,
                tspan     = 0:10,
@@ -403,16 +399,9 @@ U_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 1L, 0L, 1L, 0L, 1L,
                           0L, 15L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L,
                           0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L,
                           0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L),
-                        .Dim = c(36L, 11L),
-                        .Dimnames = list(c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                                         c("0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10")))
+                        .Dim = c(36L, 11L))
 
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(trajectory(result, as.is = TRUE), U_expected))
@@ -422,7 +411,9 @@ stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
 
 if (SimInf:::have_openmp()) {
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U_expected))
@@ -440,16 +431,14 @@ if (SimInf:::have_openmp()) {
 ##
 ## No individuals at t = 0
 ## At t = 1, all individuals enter in susceptible state
-u0 <- structure(list(S_1 = c(0, 0, 0, 0, 0, 0),
-                     I_1 = c(0, 0, 0, 0, 0, 0),
-                     S_2 = c(0, 0, 0, 0, 0, 0),
-                     I_2 = c(0, 0, 0, 0, 0, 0),
-                     S_3 = c(0, 0, 0, 0, 0, 0),
-                     I_3 = c(0, 0, 0, 0, 0, 0)),
-                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                row.names = c(NA, -6L), class = "data.frame")
+u0 <- data.frame(S_1 = c(0, 0, 0, 0, 0, 0),
+                 I_1 = c(0, 0, 0, 0, 0, 0),
+                 S_2 = c(0, 0, 0, 0, 0, 0),
+                 I_2 = c(0, 0, 0, 0, 0, 0),
+                 S_3 = c(0, 0, 0, 0, 0, 0),
+                 I_3 = c(0, 0, 0, 0, 0, 0))
 
-events <- structure(list(
+events <- data.frame(
     event      = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     time       = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     node       = c(2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 6),
@@ -457,10 +446,7 @@ events <- structure(list(
     n          = c(1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5),
     proportion = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     select     = c(1, 2, 3, 1, 2, 3, 1, 2, 3, 1, 2, 3, 1, 2, 3),
-    shift      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)),
-    .Names = c("event", "time", "node", "dest",
-               "n", "proportion", "select", "shift"),
-    row.names = c(NA, -15L), class = "data.frame")
+    shift      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
 
 model <- SISe3(u0        = u0,
                tspan     = 0:10,
@@ -519,16 +505,9 @@ U_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L,
                           0L, 0L, 0L, 1L, 0L, 1L, 0L, 1L, 0L, 2L, 0L,
                           2L, 0L, 2L, 0L, 3L, 0L, 3L, 0L, 3L, 0L, 4L,
                           0L, 4L, 0L, 4L, 0L, 5L, 0L, 5L, 0L, 5L, 0L),
-                        .Dim = c(36L, 11L),
-                        .Dimnames = list(c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                                         c("0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10")))
+                        .Dim = c(36L, 11L))
 
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(trajectory(result, as.is = TRUE), U_expected))
@@ -538,7 +517,9 @@ stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
 
 if (SimInf:::have_openmp()) {
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U_expected))
@@ -556,16 +537,14 @@ if (SimInf:::have_openmp()) {
 ## of becoming infected.
 ##
 ## At t = 3, all individuals exit.
-u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
-                     I_1 = c(0, 0, 0, 0, 0, 0),
-                     S_2 = c(0, 1, 2, 3, 4, 5),
-                     I_2 = c(0, 0, 0, 0, 0, 0),
-                     S_3 = c(0, 1, 2, 3, 4, 5),
-                     I_3 = c(0, 0, 0, 0, 0, 0)),
-                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                row.names = c(NA, -6L), class = "data.frame")
+u0 <- data.frame(S_1 = c(0, 1, 2, 3, 4, 5),
+                 I_1 = c(0, 0, 0, 0, 0, 0),
+                 S_2 = c(0, 1, 2, 3, 4, 5),
+                 I_2 = c(0, 0, 0, 0, 0, 0),
+                 S_3 = c(0, 1, 2, 3, 4, 5),
+                 I_3 = c(0, 0, 0, 0, 0, 0))
 
-events <- structure(list(
+events <- data.frame(
     event      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
     time       = c(3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3),
     node       = c(2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 6),
@@ -573,10 +552,7 @@ events <- structure(list(
     n          = c(1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5),
     proportion = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
     select     = c(4, 5, 6, 4, 5, 6, 4, 5, 6, 4, 5, 6, 4, 5, 6),
-    shift      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)),
-    .Names = c("event", "time", "node", "dest",
-               "n", "proportion", "select", "shift"),
-    row.names = c(NA, -15L), class = "data.frame")
+    shift      = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))
 
 model <- SISe3(u0        = u0,
                tspan     = 0:10,
@@ -635,16 +611,9 @@ U_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 1L, 0L, 1L, 0L, 1L,
                           0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L,
                           0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L,
                           0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L),
-                        .Dim = c(36L, 11L),
-                        .Dimnames = list(c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                                         c("0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10")))
+                        .Dim = c(36L, 11L))
 
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(trajectory(result, as.is = TRUE), U_expected))
@@ -654,7 +623,9 @@ stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
 
 if (SimInf:::have_openmp()) {
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U_expected))
@@ -673,26 +644,21 @@ if (SimInf:::have_openmp()) {
 ##
 ## At t = 3, all individuals in age category 1 age.
 ## At t = 6, all individuals in age category 2 age.
-u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
-                     I_1 = c(0, 0, 0, 0, 0, 0),
-                     S_2 = c(0, 1, 2, 3, 4, 5),
-                     I_2 = c(0, 0, 0, 0, 0, 0),
-                     S_3 = c(0, 1, 2, 3, 4, 5),
-                     I_3 = c(0, 0, 0, 0, 0, 0)),
-                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                row.names = c(NA, -6L), class = "data.frame")
+u0 <- data.frame(S_1 = c(0, 1, 2, 3, 4, 5),
+                 I_1 = c(0, 0, 0, 0, 0, 0),
+                 S_2 = c(0, 1, 2, 3, 4, 5),
+                 I_2 = c(0, 0, 0, 0, 0, 0),
+                 S_3 = c(0, 1, 2, 3, 4, 5),
+                 I_3 = c(0, 0, 0, 0, 0, 0))
 
-events <- structure(list(event      = c(2, 2, 2, 2, 2, 2, 2, 2, 2, 2),
-                         time       = c(3, 3, 3, 3, 3, 6, 6, 6, 6, 6),
-                         node       = c(2, 3, 4, 5, 6, 2, 3, 4, 5, 6),
-                         dest       = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
-                         n          = c(1, 2, 3, 4, 5, 2, 4, 6, 8, 10),
-                         proportion = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
-                         select     = c(4, 4, 4, 4, 4, 5, 5, 5, 5, 5),
-                         shift      = c(1, 1, 1, 1, 1, 2, 2, 2, 2, 2)),
-                    .Names = c("event", "time", "node", "dest",
-                        "n", "proportion", "select", "shift"),
-                    row.names = c(NA, -10L), class = "data.frame")
+events <- data.frame(event      = c(2, 2, 2, 2, 2, 2, 2, 2, 2, 2),
+                     time       = c(3, 3, 3, 3, 3, 6, 6, 6, 6, 6),
+                     node       = c(2, 3, 4, 5, 6, 2, 3, 4, 5, 6),
+                     dest       = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
+                     n          = c(1, 2, 3, 4, 5, 2, 4, 6, 8, 10),
+                     proportion = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
+                     select     = c(4, 4, 4, 4, 4, 5, 5, 5, 5, 5),
+                     shift      = c(1, 1, 1, 1, 1, 2, 2, 2, 2, 2))
 
 model <- SISe3(u0        = u0,
                tspan     = 0:10,
@@ -752,16 +718,9 @@ U_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 1L, 0L, 1L, 0L, 1L,
                           0L, 0L, 0L, 0L, 6L, 0L, 0L, 0L, 0L, 0L, 9L,
                           0L, 0L, 0L, 0L, 0L, 12L, 0L, 0L, 0L, 0L, 0L,
                           15L, 0L),
-                        .Dim = c(36L, 11L),
-                        .Dimnames = list(c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3",
-                                           "S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                                         c("0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10")))
+                        .Dim = c(36L, 11L))
 
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
 stopifnot(identical(trajectory(result, as.is = TRUE), U_expected))
@@ -771,7 +730,9 @@ stopifnot(identical(model@u0, result@u0))
 stopifnot(identical(model@events, result@events))
 
 if (SimInf:::have_openmp()) {
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
     stopifnot(identical(result_omp@U, U_expected))
@@ -789,14 +750,12 @@ if (SimInf:::have_openmp()) {
 ## becoming infected and then return to susceptible.
 ##
 ## No scheduled events
-u0 <- structure(list(S_1 = c(0, 1, 2, 3, 4, 5),
-                     I_1 = c(0, 0, 0, 0, 0, 0),
-                     S_2 = c(0, 1, 2, 3, 4, 5),
-                     I_2 = c(0, 0, 0, 0, 0, 0),
-                     S_3 = c(0, 1, 2, 3, 4, 5),
-                     I_3 = c(0, 0, 0, 0, 0, 0)),
-                .Names = c("S_1", "I_1", "S_2", "I_2", "S_3", "I_3"),
-                row.names = c(NA, -6L), class = "data.frame")
+u0 <- data.frame(S_1 = c(0, 1, 2, 3, 4, 5),
+                 I_1 = c(0, 0, 0, 0, 0, 0),
+                 S_2 = c(0, 1, 2, 3, 4, 5),
+                 I_2 = c(0, 0, 0, 0, 0, 0),
+                 S_3 = c(0, 1, 2, 3, 4, 5),
+                 I_3 = c(0, 0, 0, 0, 0, 0))
 
 model <- SISe3(u0        = u0,
                tspan     = 0:10,
@@ -820,11 +779,11 @@ model <- SISe3(u0        = u0,
                epsilon   = 1)
 
 set.seed(123)
-result <- run(model, threads = 1)
+result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
-stopifnot(identical(sum(trajectory(result, as.is = TRUE)[1:6,]), 0L))
-stopifnot(all(apply(trajectory(result, as.is = TRUE)[7:36,], 1, any)))
+stopifnot(identical(sum(trajectory(result, as.is = TRUE)[1:6, ]), 0L))
+stopifnot(all(apply(trajectory(result, as.is = TRUE)[7:36, ], 1, any)))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
@@ -832,11 +791,13 @@ stopifnot(identical(model@events, result@events))
 
 if (SimInf:::have_openmp()) {
     set.seed(123)
-    result_omp <- run(model, threads = 2)
+    set_num_threads(2)
+    result_omp <- run(model)
+    set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
-    stopifnot(identical(sum(result_omp@U[1:6,]), 0L))
-    stopifnot(all(apply(result_omp@U[7:36,], 1, any)))
+    stopifnot(identical(sum(result_omp@U[1:6, ]), 0L))
+    stopifnot(all(apply(result_omp@U[7:36, ], 1, any)))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
@@ -861,34 +822,27 @@ model <- SISe(u0      = data.frame(S = 99, I = 1),
               end_t4  = 365,
               epsilon = 0.000011)
 
-.Call("SISe_run", model, NULL, NULL, PACKAGE = "SimInf")
-.Call("SISe_run", model, 1L, NULL, PACKAGE = "SimInf")
-.Call("SISe_run", model, 1, NULL, PACKAGE = "SimInf")
+.Call(SimInf:::SISe_run, model, NULL, NULL)
+.Call(SimInf:::SISe_run, model, 1L, NULL)
+.Call(SimInf:::SISe_run, model, 1, NULL)
 
-res <- tools::assertError(.Call("SISe_run", model, -1L, NULL, PACKAGE = "SimInf"))
-stopifnot(length(grep("Invalid 'threads' value",
-                      res[[1]]$message)) > 0)
+res <- assertError(set_num_threads(-1L))
+check_error(res, "'threads' must be an integer >= 1.")
 
-res <- tools::assertError(.Call("SISe_run", model, -1, NULL, PACKAGE = "SimInf"))
-stopifnot(length(grep("Invalid 'threads' value",
-                      res[[1]]$message)) > 0)
+res <- assertError(set_num_threads(-1))
+check_error(res, "'threads' must be an integer >= 1.")
 
-res <- tools::assertError(.Call("SISe_run", model, "1", NULL, PACKAGE = "SimInf"))
-stopifnot(length(grep("Invalid 'threads' value",
-                      res[[1]]$message)) > 0)
+res <- assertError(set_num_threads("1"))
+check_error(res, "'threads' must be an integer >= 1.")
 
-res <- tools::assertError(.Call("SISe_run", model, c(1L, 1L), NULL, PACKAGE = "SimInf"))
-stopifnot(length(grep("Invalid 'threads' value",
-                      res[[1]]$message)) > 0)
+res <- assertError(set_num_threads(c(1L, 1L)))
+check_error(res, "'threads' must be an integer >= 1.")
 
-res <- tools::assertError(.Call("SISe_run", model, c(1, 1), NULL, PACKAGE = "SimInf"))
-stopifnot(length(grep("Invalid 'threads' value",
-                      res[[1]]$message)) > 0)
+res <- assertError(set_num_threads(c(1, 1)))
+check_error(res, "'threads' must be an integer >= 1.")
 
-res <- tools::assertError(.Call("SISe_run", model, NA_integer_, NULL, PACKAGE = "SimInf"))
-stopifnot(length(grep("Invalid 'threads' value",
-                      res[[1]]$message)) > 0)
+res <- assertError(set_num_threads(NA_integer_))
+check_error(res, "'threads' must be an integer >= 1.")
 
-res <- tools::assertError(.Call("SISe_run", model, NA_real_, NULL, PACKAGE = "SimInf"))
-stopifnot(length(grep("Invalid 'threads' value",
-                      res[[1]]$message)) > 0)
+res <- assertError(set_num_threads(NA_real_))
+check_error(res, "'threads' must be an integer >= 1.")
